pub struct ControlCommand {
pub action: i32,
pub pattern_name: Option<String>,
}Fields
action: i32pattern_name: Option<String>Optional pattern to trigger (for TriggerPattern action)
Implementations
Sourceimpl ControlCommand
impl ControlCommand
Sourcepub fn action(&self) -> ControlAction
pub fn action(&self) -> ControlAction
Returns the enum value of action, or the default if the field is set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: ControlAction)
pub fn set_action(&mut self, value: ControlAction)
Sets action to the provided enum value.
Sourcepub fn pattern_name(&self) -> &str
pub fn pattern_name(&self) -> &str
Returns the value of pattern_name, or the default value if pattern_name is unset.